@@ -383,10 +383,12 @@ sub SearchFieldRender {
     # Assemble display values
     # If there are no available values, leave it empty.
     if ( IsHashRefWithData($SelectionData) ) {
+        my $TicketID = $Param{LayoutObject}->{TicketID};
         $SelectionData = $DynamicFieldWebserviceObject->DisplayValueGet(
             DynamicFieldConfig => $Param{DynamicFieldConfig},
             Value              => [ keys %{$SelectionData} ],
             Limit              => '',
+            TicketID           => $TicketID,
         );
     }
 
@@ -450,10 +452,12 @@ sub _AutocompleteSearchFieldRender {
 
     my $SelectionData = {};
     if ( IsArrayRefWithData($FieldValues) ) {
+        my $TicketID = $Param{LayoutObject}->{TicketID};
         $SelectionData = $DynamicFieldWebserviceObject->DisplayValueGet(
             DynamicFieldConfig => $Param{DynamicFieldConfig},
             Value              => $FieldValues,
             Limit              => '',
+            TicketID           => $TicketID,
         );
     }
 
@@ -541,9 +545,11 @@ sub ValueLookup {
 
     return $Param{Key} if !IsStringWithData( $Param{Key} );
 
-    my $Value = $DynamicFieldWebserviceObject->DisplayValueGet(
+    my $TicketID = $Param{LayoutObject}->{TicketID};
+    my $Value    = $DynamicFieldWebserviceObject->DisplayValueGet(
         DynamicFieldConfig => $Param{DynamicFieldConfig},
         Value              => $Param{Key},
+        TicketID           => $TicketID,
     );
 
     return $Value;
@@ -679,6 +685,7 @@ sub PossibleValuesGet {
     # values yet.
     $PossibleValues{' '} = '';
 
+    my $TicketID = $Param{LayoutObject}->{TicketID};
     if ( $Param{DynamicFieldConfig}->{Config}->{InitialSearchTerm} ) {
         my $InitialSearchTerm = $LayoutObject->Ascii2Html(
             Text => $Param{DynamicFieldConfig}->{Config}->{InitialSearchTerm},
@@ -688,6 +695,7 @@ sub PossibleValuesGet {
             DynamicFieldConfig => $Param{DynamicFieldConfig},
             SearchTerms        => $InitialSearchTerm,
             UserID             => $Param{UserID},
+            TicketID           => $TicketID,
         );
         if ( IsArrayRefWithData($Results) ) {
             for my $Result ( @{$Results} ) {
@@ -708,6 +716,7 @@ sub PossibleValuesGet {
         my $DisplayValue = $DynamicFieldWebserviceObject->DisplayValueGet(
             DynamicFieldConfig => $Param{DynamicFieldConfig},
             Value              => [ $Param{Value} ],
+            TicketID           => $TicketID,
         );
 
         %PossibleValues = (
